@@ -48,6 +48,7 @@ import (
 
 	"github.com/twpayne/chezmoi/v2/assets/templates"
 	"github.com/twpayne/chezmoi/v2/pkg/chezmoi"
+	"github.com/twpayne/chezmoi/v2/pkg/chezmoilog"
 	"github.com/twpayne/chezmoi/v2/pkg/git"
 )
 
@@ -82,6 +83,7 @@ type ConfigFile struct {
 	ScriptTempDir      chezmoi.AbsPath                 `mapstructure:"scriptTempDir"`
 	SourceDirAbsPath   chezmoi.AbsPath                 `mapstructure:"sourceDir"`
 	Template           templateConfig                  `mapstructure:"template"`
+	TextConv           textConv                        `mapstructure:"textConv"`
 	Umask              fs.FileMode                     `mapstructure:"umask"`
 	UseBuiltinAge      autoBool                        `mapstructure:"useBuiltinAge"`
 	UseBuiltinGit      autoBool                        `mapstructure:"useBuiltinGit"`
@@ -460,6 +462,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		"pass":                     c.passTemplateFunc,
 		"passFields":               c.passFieldsTemplateFunc,
 		"passRaw":                  c.passRawTemplateFunc,
+		"quoteList":                c.quoteListTemplateFunc,
 		"secret":                   c.secretTemplateFunc,
 		"secretJSON":               c.secretJSONTemplateFunc,
 		"stat":                     c.statTemplateFunc,
@@ -647,6 +650,7 @@ func (c *Config) applyArgs(
 // cmdOutput returns the of running the command name with args in dirAbsPath.
 func (c *Config) cmdOutput(dirAbsPath chezmoi.AbsPath, name string, args []string) ([]byte, error) {
 	cmd := exec.Command(name, args...)
+	cmd.Stderr = os.Stderr
 	if !dirAbsPath.Empty() {
 		dirRawAbsPath, err := c.baseSystem.RawPath(dirAbsPath)
 		if err != nil {
@@ -654,7 +658,7 @@ func (c *Config) cmdOutput(dirAbsPath chezmoi.AbsPath, name string, args []strin
 		}
 		cmd.Dir = dirRawAbsPath.String()
 	}
-	return c.baseSystem.IdempotentCmdOutput(cmd)
+	return chezmoilog.LogCmdOutput(cmd)
 }
 
 // colorAutoFunc detects whether color should be used.
@@ -1019,7 +1023,7 @@ func (c *Config) destAbsPathInfos(
 		if err != nil {
 			return nil, err
 		}
-		if _, err := destAbsPath.TrimDirPrefix(c.DestDirAbsPath); err != nil {
+		if _, err := c.targetRelPath(destAbsPath); err != nil {
 			return nil, err
 		}
 		if options.recursive {
@@ -1398,9 +1402,10 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 func (c *Config) newDiffSystem(s chezmoi.System, w io.Writer, dirAbsPath chezmoi.AbsPath) chezmoi.System {
 	if c.Diff.useBuiltinDiff || c.Diff.Command == "" {
 		options := &chezmoi.GitDiffSystemOptions{
-			Color:   c.Color.Value(c.colorAutoFunc),
-			Include: c.Diff.include.Sub(c.Diff.Exclude),
-			Reverse: c.Diff.Reverse,
+			Color:        c.Color.Value(c.colorAutoFunc),
+			Include:      c.Diff.include.Sub(c.Diff.Exclude),
+			Reverse:      c.Diff.Reverse,
+			TextConvFunc: c.TextConv.convert,
 		}
 		return chezmoi.NewGitDiffSystem(s, w, dirAbsPath, options)
 	}
@@ -1540,7 +1545,7 @@ func (c *Config) pageOutputString(output, cmdPager string) error {
 	pagerCmd.Stdin = bytes.NewBufferString(output)
 	pagerCmd.Stdout = c.stdout
 	pagerCmd.Stderr = c.stderr
-	return pagerCmd.Run()
+	return chezmoilog.LogCmdRun(pagerCmd)
 }
 
 // persistentPreRunRootE performs pre-run actions for the root command.
@@ -1935,6 +1940,15 @@ func (c *Config) sourceDirAbsPath() (chezmoi.AbsPath, error) {
 	}
 }
 
+func (c *Config) targetRelPath(absPath chezmoi.AbsPath) (chezmoi.RelPath, error) {
+	relPath, err := absPath.TrimDirPrefix(c.DestDirAbsPath)
+	var notInAbsDirError *chezmoi.NotInAbsDirError
+	if errors.As(err, &notInAbsDirError) {
+		return chezmoi.EmptyRelPath, fmt.Errorf("%s: not in destination directory (%s)", absPath, c.DestDirAbsPath)
+	}
+	return relPath, err
+}
+
 type targetRelPathsOptions struct {
 	mustBeInSourceState bool
 	recursive           bool
@@ -1951,7 +1965,7 @@ func (c *Config) targetRelPaths(
 		if err != nil {
 			return nil, err
 		}
-		targetRelPath, err := argAbsPath.TrimDirPrefix(c.DestDirAbsPath)
+		targetRelPath, err := c.targetRelPath(argAbsPath)
 		if err != nil {
 			return nil, err
 		}
